@@ -1,10 +1,8 @@
 from math import ceil
 from typing import Optional
 from typing import Tuple
-from typing import Union
 
 import torch
-from torch import Tensor
 
 from pfhedge._utils.doc import _set_attr_and_docstring
 from pfhedge._utils.doc import _set_docstring
