@@ -9,23 +9,24 @@ from torch import Tensor
 from pfhedge._utils.doc import _set_attr_and_docstring
 from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
+from pfhedge._utils.typing import TensorOrScalar
 from pfhedge.stochastic import generate_heston
 
 from .base import Primary
 
-TensorOrFloat = Union[Tensor, float]
-
 
 class HestonStock(Primary):
-    """A stock of which spot price and variance follow Heston process.
+    r"""A stock of which spot price and variance follow Heston process.
 
-    See :func:`pfhedge.stochastic.generate_heston` for details of the process.
+    .. seealso::
+        - :func:`pfhedge.stochastic.generate_heston`:
+          The stochastic process.
 
     Args:
-        kappa (float, default=1.0): The parameter :math:`\\kappa`.
-        theta (float, default=0.04): The parameter :math:`\\theta`.
-        sigma (float, default=2.0): The parameter :math:`\\sigma`.
-        rho (float, default=-0.7): The parameter :math:`\\rho`.
+        kappa (float, default=1.0): The parameter :math:`\kappa`.
+        theta (float, default=0.04): The parameter :math:`\theta`.
+        sigma (float, default=2.0): The parameter :math:`\sigma`.
+        rho (float, default=-0.7): The parameter :math:`\rho`.
         cost (float, default=0.0): The transaction cost rate.
         dt (float, default=1/250): The intervals of the time steps.
         dtype (torch.device, optional): Desired device of returned tensor.
@@ -104,7 +105,7 @@ class HestonStock(Primary):
         self,
         n_paths: int = 1,
         time_horizon: float = 20 / 250,
-        init_state: Optional[Tuple[TensorOrFloat, ...]] = None,
+        init_state: Optional[Tuple[TensorOrScalar, ...]] = None,
     ) -> None:
         """Simulate the spot price and add it as a buffer named ``spot``.
 
