@@ -108,13 +108,13 @@ def european_binary_payoff(
 
 
 def exp_utility(input: Tensor, a: float = 1.0) -> Tensor:
-    """Applies an exponential utility function.
+    r"""Applies an exponential utility function.
 
     An exponential utility function is defined as:
 
     .. math::
 
-        u(x) = -\\exp(-a x) \\,.
+        u(x) = -\exp(-a x) \,.
 
     Args:
         input (torch.Tensor): The input tensor.
@@ -128,16 +128,16 @@ def exp_utility(input: Tensor, a: float = 1.0) -> Tensor:
 
 
 def isoelastic_utility(input: Tensor, a: float) -> Tensor:
-    """Applies an isoelastic utility function.
+    r"""Applies an isoelastic utility function.
 
     An isoelastic utility function is defined as:
 
     .. math::
 
-        u(x) = \\begin{cases}
-        x^{1 - a} & a \\neq 1 \\\\
-        \\log{x} & a = 1
-        \\end{cases} \\,.
+        u(x) = \begin{cases}
+        x^{1 - a} & a \neq 1 \\
+        \log{x} & a = 1
+        \end{cases} \,.
 
     Args:
         input (torch.Tensor): The input tensor.
@@ -153,6 +153,14 @@ def isoelastic_utility(input: Tensor, a: float) -> Tensor:
         return input.pow(1.0 - a)
 
 
+def entropic_risk_measure(input: Tensor, a: float = 1.0) -> Tensor:
+    """Returns the entropic risk measure.
+
+    See :class:`pfhedge.nn.EntropicRiskMeasure` for details.
+    """
+    return (-exp_utility(input, a=a).mean(0)).log() / a
+
+
 def topp(input: Tensor, p: float, dim: Optional[int] = None, largest: bool = True):
     """Returns the largest :math:`p * N` elements of the given input tensor,
     where :math:`N` stands for the total number of elements in the input tensor.
@@ -166,7 +174,7 @@ def topp(input: Tensor, p: float, dim: Optional[int] = None, largest: bool = Tru
 
     Args:
         input (torch.Tensor): The input tensor.
-        p (float): Quantile level.
+        p (float): The quantile level.
         dim (int, optional): The dimension to sort along.
         largest (bool, default=True): Controls whether to return largest or smallest
             elements.
@@ -175,7 +183,6 @@ def topp(input: Tensor, p: float, dim: Optional[int] = None, largest: bool = Tru
         torch.Tensor
 
     Examples:
-
         >>> from pfhedge.nn.functional import topp
         >>>
         >>> input = torch.arange(1.0, 6.0)
@@ -197,16 +204,17 @@ def expected_shortfall(input: Tensor, p: float, dim: Optional[int] = None) -> Te
 
     Args:
         input (torch.Tensor): The input tensor.
-        p (float): Quantile level.
+        p (float): The quantile level.
         dim (int, optional): The dimension to sort along.
 
     Examples:
-
         >>> from pfhedge.nn.functional import expected_shortfall
         >>>
-        >>> input = -torch.arange(1., 6.)
-        >>> expected_shortfall(input, 3 / 5)
-        tensor(4.)
+        >>> input = -torch.arange(10.0)
+        >>> input
+        tensor([-0., -1., -2., -3., -4., -5., -6., -7., -8., -9.])
+        >>> expected_shortfall(input, 0.3)
+        tensor(8.)
 
     Returns:
         torch.Tensor
@@ -217,6 +225,52 @@ def expected_shortfall(input: Tensor, p: float, dim: Optional[int] = None) -> Te
         return -topp(input, p=p, largest=False, dim=dim).values.mean(dim=dim)
 
 
+def _min_values(input: Tensor, dim: Optional[int] = None) -> Tensor:
+    return input.min() if dim is None else input.min(dim=dim).values
+
+
+def _max_values(input: Tensor, dim: Optional[int] = None) -> Tensor:
+    return input.max() if dim is None else input.max(dim=dim).values
+
+
+def value_at_risk(input: Tensor, p: float, dim: Optional[int] = None) -> Tensor:
+    """Returns the value at risk of the given input tensor.
+
+    Note:
+        If :math:`p \leq 1 / N`` with :math:`N` being the number of elements to sort,
+        returns the smallest element in the tensor.
+        If :math:`p > 1 - 1 / N``, returns the largest element in the tensor.
+
+    Args:
+        input (torch.Tensor): The input tensor.
+        p (float): The quantile level.
+        dim (int, optional): The dimension to sort along.
+
+    Examples:
+        >>> from pfhedge.nn.functional import value_at_risk
+        >>>
+        >>> input = -torch.arange(10.0)
+        >>> input
+        tensor([-0., -1., -2., -3., -4., -5., -6., -7., -8., -9.])
+        >>> value_at_risk(input, 0.3)
+        tensor(-7.)
+
+    Returns:
+        torch.Tensor
+    """
+    n = input.numel() if dim is None else input.size(dim)
+
+    if p <= 1 / n:
+        output = _min_values(input, dim=dim)
+    elif p > 1 - 1 / n:
+        output = _max_values(input, dim=dim)
+    else:
+        q = (p - (1 / n)) / (1 - (1 / n))
+        output = input.quantile(q, dim=dim)
+
+    return output
+
+
 def leaky_clamp(
     input: Tensor,
     min: Optional[Tensor] = None,
@@ -224,7 +278,7 @@ def leaky_clamp(
     clamped_slope: float = 0.01,
     inverted_output: str = "mean",
 ) -> Tensor:
-    """Leakily clamp all elements in ``input`` into the range :math:`[\\min, \\max]`.
+    r"""Leakily clamp all elements in ``input`` into the range :math:`[\min, \max]`.
 
     See :class:`pfhedge.nn.LeakyClamp` for details.
     """
@@ -256,7 +310,7 @@ def clamp(
     max: Optional[Tensor] = None,
     inverted_output: str = "mean",
 ) -> Tensor:
-    """Clamp all elements in ``input`` into the range :math:`[\\min, \\max]`.
+    r"""Clamp all elements in ``input`` into the range :math:`[\min, \max]`.
 
     See :class:`pfhedge.nn.Clamp` for details.
     """
@@ -270,14 +324,14 @@ def clamp(
 
 
 def realized_variance(input: Tensor, dt: TensorOrScalar) -> Tensor:
-    """Returns the realized variance of the price.
+    r"""Returns the realized variance of the price.
 
-    Realized variance :math:`\\sigma^2` of the stock price :math:`S` is defined as:
+    Realized variance :math:`\sigma^2` of the stock price :math:`S` is defined as:
 
     .. math::
 
-        \\sigma^2 = \\frac{1}{T - 1} \\sum_{i = 1}^{T - 1}
-        \\frac{1}{dt} \\log(S_{i + 1} / S_i)^2
+        \sigma^2 = \frac{1}{T - 1} \sum_{i = 1}^{T - 1}
+        \frac{1}{dt} \log(S_{i + 1} / S_i)^2
 
     where :math:`T` is the number of time steps.
 
@@ -326,20 +380,20 @@ def terminal_value(
     cost: float = 0.0,
     payoff: Optional[Tensor] = None,
     deduct_first_cost: bool = True,
-):
-    """Returns the terminal portfolio value.
+) -> Tensor:
+    r"""Returns the terminal portfolio value.
 
     The terminal value of a hedger's portfolio is given by
 
     .. math::
 
-        \\text{PL}(Z, \\delta, S) =
+        \text{PL}(Z, \delta, S) =
         - Z
-        + \\sum_{i = 0}^{T - 2} \\delta_{i - 1} (S_{i} - S_{i - 1})
-        - c \\sum_{i = 0}^{T - 1} |\\delta_{i} - \\delta_{i - 1}| S_{i}
+        + \sum_{i = 0}^{T - 2} \delta_{i - 1} (S_{i} - S_{i - 1})
+        - c \sum_{i = 0}^{T - 1} |\delta_{i} - \delta_{i - 1}| S_{i}
 
     where :math:`Z` is the payoff of the derivative, :math:`T` is the number of
-    time steps, :math:`S` is the spot price, :math:`\\delta` is the signed number
+    time steps, :math:`S` is the spot price, :math:`\delta` is the signed number
     of shares held at each time step.
     We define :math:`\delta_0 = 0` for notational convenience.
 
@@ -358,7 +412,7 @@ def terminal_value(
     Args:
         spot (torch.Tensor): The spot price of the underlying asset :math:`S`.
         unit (torch.Tensor): The signed number of shares of the underlying asset
-            :math:`\\delta`.
+            :math:`\delta`.
         cost (float, default=0.0): The proportional transaction cost rate of
             the underlying asset :math:`c`.
         payoff (torch.Tensor, optional): The payoff of the derivative :math:`Z`.
@@ -434,7 +488,19 @@ def npdf(input: Tensor) -> Tensor:
 
 
 def d1(log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor) -> Tensor:
-    """Returns :math:`d_1` in the Black-Scholes formula.
+    r"""Returns :math:`d_1` in the Black-Scholes formula.
+
+    .. math::
+
+        d_1 = \frac{s + \frac12 \sigma^2 t}{\sigma \sqrt{t}}
+
+    where
+    :math:`s` is the log moneyness,
+    :math:`t` is the time to maturity, and
+    :math:`\sigma` is the volatility.
+
+    Note:
+        Risk-free rate is set to zero.
 
     Args:
         log_moneyness (torch.Tensor or float): Log moneyness of the underlying asset.
@@ -449,7 +515,19 @@ def d1(log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor) -> T
 
 
 def d2(log_moneyness: Tensor, time_to_maturity: Tensor, volatility: Tensor) -> Tensor:
-    """Returns :math:`d_2` in the Black-Scholes formula.
+    r"""Returns :math:`d_2` in the Black-Scholes formula.
+
+    .. math::
+
+        d_2 = \frac{s - \frac12 \sigma^2 t}{\sigma \sqrt{t}}
+
+    where
+    :math:`s` is the log moneyness,
+    :math:`t` is the time to maturity, and
+    :math:`\sigma` is the volatility.
+
+    Note:
+        Risk-free rate is set to zero.
 
     Args:
         log_moneyness (torch.Tensor or float): Log moneyness of the underlying asset.
